@@ -1,5 +1,6 @@
 #! /usr/bin/env python -tt
-
+# vim: set fileencoding=utf-8
+from __future__ import unicode_literals
 """
 Hierarchical Yaml Python Config
 ===============================
@@ -24,7 +25,6 @@ import yaml
 import logging
 from jinja2 import Environment, Undefined, DebugUndefined,StrictUndefined
 
-
 __all__ = [
     'load',
     'dump',
@@ -47,7 +47,12 @@ class HiYaPyCoImplementationException(Exception):
     """dummy Exception raised if we are unable to merge some YAML stuff"""
     pass
 
-primitiveTypes = (int, str, bool, float)
+try:
+    primitiveTypes = (int, str, bool, float, unicode)
+    strTypes = (str, unicode)
+except NameError:
+    primitiveTypes = (int, str, bool, float)
+    strTypes = (str)
 listTypes = (list, tuple)
 
 # you may set this to something suitable for you
@@ -132,12 +137,13 @@ class HiYaPyCo():
                     self._data = self._simplemerge(self._data, ydata)
                 else:
                     self._data = self._deepmerge(self._data, ydata)
+                logger.debug('merged data: %s' % self._data)
 
         if self.interpolate:
             self._data = self._interpolate(self._data)
 
     def _updatefiles(self, arg):
-        if isinstance(arg, str):
+        if isinstance(arg, strTypes):
             if arg in self._files:
                 logger.warn('ignoring duplicated file %s' % arg)
                 return
@@ -149,10 +155,10 @@ class HiYaPyCo():
             raise HiYaPyCoInvocationException('unable to handle arg %s of type %s' % (arg, type(arg),))
 
     def _interpolate(self, d):
-        logger.debug('interpolate "%s" ...' % d)
+        logger.debug('interpolate "%s" of type %s ...' % (d, type(d),))
         if d is None:
             return None
-        if isinstance(d, str):
+        if isinstance(d, strTypes):
             return self._interpolatestr(d)
         if isinstance(d, primitiveTypes):
             return d
